package de.cliffbreak.varo.uitls;

import java.util.Calendar;

import net.md_5.bungee.api.chat.ClickEvent;
import net.md_5.bungee.api.chat.ComponentBuilder;
import net.md_5.bungee.api.chat.HoverEvent;
import net.md_5.bungee.api.chat.TextComponent;

public class MessageUtils {

    public static String getTimestampedMessage(String message) {

        return " §8" + getTimestamp() + " §7| " + message;
    }

    /**
     * Create a TextComponent with a more detailed player name on hover
     * 
     * @param player
     *                    the playername the message should be sent from
     * @param message
     *                    the message to send
     * @return TextComponent
     */
    public static TextComponent getRichTextComponent(String player, String message) {
        return getRichTextComponent(player, message, false, true);
    }

    /**
     * Create a TextComponent with a more detailed player name on hover
     * 
     * @param player
     *                             the playername the message should be sent from
     * @param message
     *                             the message to send
     * @param isServiceMessage
     *                             is this a service message (f.e. PlayerJoinEvent)
     * @return TextComponent
     */
    public static TextComponent getRichTextComponent(String player, String message, boolean isServiceMessage) {
        return getRichTextComponent(player, message, isServiceMessage, true);
    }

    /**
     * Create a TextComponent with a more detailed player name on hover and an optional timestamp
     * 
     * @param player
     *                             the playername the message should be sent from
     * @param message
     *                             the message to send
     * @param isServiceMessage
     *                             is this a service message (f.e. PlayerJoinEvent)
     * @param useTimestamp
     *                             should a timestamp be returned?
     * @return TextComponent
     */
    public static TextComponent getRichTextComponent(String player, String message, boolean isServiceMessage,
            boolean useTimestamp) {
        TextComponent mainComponent = new TextComponent(" ");
        TextComponent timeComponent = new TextComponent("§8" + getTimestamp() + " §7| ");
        TextComponent playerComponent = new TextComponent("§b" + player);
        TextComponent messageComponent = new TextComponent(" §7>> §r§f" + message);
        timeComponent.setHoverEvent(new HoverEvent(HoverEvent.Action.SHOW_TEXT,
                new ComponentBuilder("§7" + getTimestampSeconds()).create()));
        playerComponent.setHoverEvent(new HoverEvent(HoverEvent.Action.SHOW_TEXT,
                new ComponentBuilder("§e" + "Name:" + "§r " + player + "\n§b" + "Team:" + "§r " + "kein Team :(")
                        .create()));
        playerComponent.setClickEvent(new ClickEvent(ClickEvent.Action.SUGGEST_COMMAND, "/msg " + player + " "));
        if (useTimestamp)
            mainComponent.addExtra(timeComponent);
        mainComponent.addExtra(playerComponent);
        if (!isServiceMessage)
            mainComponent.addExtra(messageComponent);
        else
            mainComponent.addExtra(message);
        return mainComponent;
    }

    private static String getTimestamp() {
        Calendar calendar = Calendar.getInstance();
        return String.format("%02d", calendar.get(Calendar.HOUR_OF_DAY)) + ":"
                + String.format("%02d", calendar.get(Calendar.MINUTE));
    }

    private static String getTimestampSeconds() {
        Calendar calendar = Calendar.getInstance();
        return String.format("%02d", calendar.get(Calendar.HOUR_OF_DAY)) + ":"
                + String.format("%02d", calendar.get(Calendar.MINUTE)) + ":"
                + String.format("%02d", calendar.get(Calendar.SECOND));
    }
}